@@ -46,7 +46,9 @@ def get_access_token(scope, grant_type=None):
     }
 
     response = requests.request("POST", TOKEN_URL, headers=headers, data=payload)
+    print(payload)
+    print(headers)
+    print(TOKEN_URL)
+    # access_token = json.loads(response.text)
 
-    access_token = json.loads(response.text)
-
-    return access_token
+    # return access_token
